@@ -24,6 +24,8 @@ get '/cached' => sub {
     return cache_page ++$counter;
 };
 
+get '/counter' => sub { $counter };
+
 get '/check_page_cache' => sub {
     check_page_cache;
 };
@@ -40,9 +42,30 @@ get '/stash' => sub {
     return cache_get 'secret_stash';
 };
 
+del '/stash' => sub {
+    return cache_remove 'secret_stash';
+};
+
 my $computed = 'aaa';
 get '/compute' => sub {
     return cache_compute compute => sub { ++$computed };
 };
 
+my $cached_quick;
+get '/expire_quick' => sub {
+    return cache_page ++$cached_quick, 2;
+};
+
+my $headers;
+before sub {
+    header 'X-Foo' => ++$headers;
+};
+
+get '/clear_headers' => sub { $headers = 0 };
+get '/headers' => sub {
+    cache_page 'gonzo';
+};
+
+
+
 1;
